<?php
/**
 * Plugin Name: BrazilPay Payment Gateway
 * Plugin URI: https://brazilpays.com/
 * Description: Gateway de pagamento via Pix e Cartão de Crédito utilizando a API BrazilPay.
 * Version: 2.7
 * Author: Megaleios
 * Author URI: https://megaleios.com
 * Text Domain: brazilpays-plugin
 * Domain Path: /languages
 * WC requires at least: 3.0.0
 * WC tested up to: 7.0.0
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

// Adicione esta função para declarar compatibilidade com HPOS
function brazilpays_declare_hpos_compatibility() {
    if (class_exists('\Automattic\WooCommerce\Utilities\FeaturesUtil')) {
        \Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility('custom_order_tables', __FILE__, true);
    }
}
add_action('before_woocommerce_init', 'brazilpays_declare_hpos_compatibility');

// Função para adicionar o intervalo personalizado de 30 minutos
add_filter('cron_schedules', 'add_brazilpays_cron_interval');

function add_brazilpays_cron_interval($schedules) {
    $schedules['every_thirty_minutes'] = array(
        'interval' => 1800, // 30 minutos em segundos
        'display'  => __('Every 30 Minutes', 'brazilpays-plugin')
    );
    return $schedules;
}

// Garante que o WooCommerce está ativo antes de inicializar o plugin
function brazilpays_init() {
    if (!class_exists('WC_Payment_Gateway')) {
        add_action('admin_notices', 'brazilpays_woocommerce_missing_notice');
        return;
    }

    // Inclua os arquivos necessários
    require_once plugin_dir_path(__FILE__) . 'includes/class-brazilpays-environment.php';
    require_once plugin_dir_path(__FILE__) . 'includes/class-brazilpays-admin-interface.php';
    require_once plugin_dir_path(__FILE__) . 'includes/class-brazilpays-gateway-credit_new.php';
    require_once plugin_dir_path(__FILE__) . 'includes/class-brazilpays-gateway-pix_new.php';
    require_once plugin_dir_path(__FILE__) . 'includes/class-brazilpays-cron-status-check.php';

    // Adicione os gateways
    add_filter('woocommerce_payment_gateways', 'add_brazilpays_gateways');
}
add_action('plugins_loaded', 'brazilpays_init', 11);

function add_brazilpays_gateways($gateways) {
    $gateways[] = 'WC_BrazilPays_Gateway_CreditNew';
    $gateways[] = 'WC_BrazilPays_Gateway_PixNew';
    return $gateways;
}

function brazilpays_woocommerce_missing_notice() {
    echo '<div class="error"><p><strong>' . __('BrazilPay Payment Gateway', 'brazilpays-plugin') . '</strong> ' . __('requer que o WooCommerce esteja instalado e ativo.', 'brazilpays-plugin') . '</p></div>';
}

// Ative o cron job ao ativar o plugin
register_activation_hook(__FILE__, 'activate_brazilpays_plugin');

function activate_brazilpays_plugin() {
    // Verifica se o intervalo personalizado existe
    if (!wp_get_schedule('every_thirty_minutes')) {
        // Se não existir, adiciona o intervalo
        add_filter('cron_schedules', 'add_brazilpays_cron_interval');
    }
    
    // Agendar o evento de verificação de status se ainda não estiver agendado
    if (!wp_next_scheduled('brazilpays_check_order_status')) {
        wp_schedule_event(time(), 'every_thirty_minutes', 'brazilpays_check_order_status');
    }
}

// Mantenha o código de desativação também
register_deactivation_hook(__FILE__, 'deactivate_brazilpays_plugin');

function deactivate_brazilpays_plugin() {
    // Limpar o agendamento do cron ao desativar o plugin
    wp_clear_scheduled_hook('brazilpays_check_order_status');
}

// Função para executar a verificação de status
add_action('brazilpays_check_order_status', 'do_brazilpays_status_check');

function do_brazilpays_status_check() {

    // Desabilita todos os e-mails do WooCommerce
    /* add_filter('woocommerce_email_enabled_new_order', '__return_false', 999);
    add_filter('woocommerce_email_enabled_cancelled_order', '__return_false', 999);
    add_filter('woocommerce_email_enabled_failed_order', '__return_false', 999);
    add_filter('woocommerce_email_enabled_customer_on_hold_order', '__return_false', 999);
    add_filter('woocommerce_email_enabled_customer_processing_order', '__return_false', 999);
    add_filter('woocommerce_email_enabled_customer_completed_order', '__return_false', 999);
    add_filter('woocommerce_email_enabled_customer_refunded_order', '__return_false', 999); */

    // Desabilita o sistema de e-mails do WooCommerce
   /*  $wc_emails = WC()->mailer()->get_emails();
    foreach ($wc_emails as $email) {
        remove_all_actions($email->trigger_hook);
    } */

    $status_checker = new BrazilPays_Cron_Status_Check();
    $status_checker->do_status_check();

    /* // Reabilita o sistema de e-mails do WooCommerce
    foreach ($wc_emails as $email) {
        add_action($email->trigger_hook, array($email, 'trigger'));
    } */


    // Reabilita os e-mails do WooCommerce
   /*  remove_filter('woocommerce_email_enabled_new_order', '__return_false', 999);
    remove_filter('woocommerce_email_enabled_cancelled_order', '__return_false', 999);
    remove_filter('woocommerce_email_enabled_failed_order', '__return_false', 999);
    remove_filter('woocommerce_email_enabled_customer_on_hold_order', '__return_false', 999);
    remove_filter('woocommerce_email_enabled_customer_processing_order', '__return_false', 999);
    remove_filter('woocommerce_email_enabled_customer_completed_order', '__return_false', 999);
    remove_filter('woocommerce_email_enabled_customer_refunded_order', '__return_false', 999);*/
} 

// Função para registrar erros de agendamento
function log_cron_errors($wp_error) {
    if (is_wp_error($wp_error)) {
        error_log('BrazilPays Cron Error: ' . $wp_error->get_error_message());
    }
}
add_action('wp_error_added', 'log_cron_errors');