<?php
class BrazilPaysAdminInterface {
    public function __construct() {
        add_action('admin_menu', array($this, 'add_plugin_page'));
        add_action('admin_init', array($this, 'page_init'));
    }

    public function add_plugin_page() {
        add_menu_page(
            'BrazilPays Settings',
            'BrazilPays',
            'manage_options',
            'brazilpays-settings',
            array($this, 'create_admin_page'),
            'dashicons-money-alt'
        );
    }

    public function create_admin_page() {
        ?>
        <div class="wrap">
            <h2>Configuração das credenciais de acesso do Plugin - Brazil Pays</h2>
            <form method="post" action="options.php">
                <?php
                settings_fields('brazilpays_option_group');
                do_settings_sections('brazilpays-settings');
                submit_button();
                ?>
            </form>
        </div>
        <?php
    }

    public function page_init() {
        register_setting('brazilpays_option_group', 'brazilpays_options', array($this, 'sanitize'));

        add_settings_section(
            'brazilpays_setting_section',
            'BrazilPays Settings',
            array($this, 'section_info'),
            'brazilpays-settings'
        );

        add_settings_field(
            'merchant_code',
            'Código do Merchant',
            array($this, 'merchant_code_callback'),
            'brazilpays-settings',
            'brazilpays_setting_section'
        );

        add_settings_field(
            'public_key',
            'API Pública',
            array($this, 'public_key_callback'),
            'brazilpays-settings',
            'brazilpays_setting_section'
        );

        add_settings_field(
            'environment',
            'Ambiente',
            array($this, 'environment_callback'),
            'brazilpays-settings',
            'brazilpays_setting_section'
        );
    }

    public function sanitize($input) {
        $sanitary_values = array();
        if (isset($input['merchant_code'])) {
            $sanitary_values['merchant_code'] = sanitize_text_field($input['merchant_code']);
        }
        if (isset($input['public_key'])) {
            $sanitary_values['public_key'] = sanitize_text_field($input['public_key']);
        }
        if (isset($input['environment'])) {
            $sanitary_values['environment'] = $input['environment'];
        }
        return $sanitary_values;
    }

    public function section_info() {
        echo 'Insira suas configurações abaixo:';
    }

    public function merchant_code_callback() {
        $options = get_option('brazilpays_options');
        printf(
            '<input type="text" id="merchant_code" name="brazilpays_options[merchant_code]" value="%s" />',
            isset($options['merchant_code']) ? esc_attr($options['merchant_code']) : ''
        );
    }

    public function public_key_callback() {
        $options = get_option('brazilpays_options');
        printf(
            '<input type="text" id="public_key" name="brazilpays_options[public_key]" value="%s" />',
            isset($options['public_key']) ? esc_attr($options['public_key']) : ''
        );
    }

    public function environment_callback() {
        $options = get_option('brazilpays_options');
        $environment = isset($options['environment']) ? $options['environment'] : 'production';
        ?>
        <select name="brazilpays_options[environment]" id="environment">
            <option value="production" <?php selected($environment, 'production'); ?>>Production</option>
            <option value="homologation" <?php selected($environment, 'homologation'); ?>>Homologation</option>
        </select>
        <?php
    }
}

if (is_admin()) {
    $brazilpays_admin = new BrazilPaysAdminInterface();
}