<?php
if (!defined('ABSPATH')) {
    exit; // Sair se acessado diretamente
}
require_once plugin_dir_path(__FILE__) . 'class-brazilpays-environment.php';

class BrazilPays_Cron_Status_Check {
    private $merchant_code;
    private $public_key;
    private $api_url;

    public function __construct() {
        add_action('init', array($this, 'init_api_credentials'));
        add_action('brazilpays_check_order_status', array($this, 'do_status_check'));
    }


    public function init_api_credentials() {
       // Obtem as configurações do BrazilPaysEnvironment
       $brazilpays_environment = BrazilPaysEnvironment::getInstance();
       $this->merchant_code = $brazilpays_environment->getMerchantCode();
       $this->public_key = $brazilpays_environment->getPublicKey();
       $this->api_url = $brazilpays_environment->getApiUrl();
        
       // error_log('BrazilPays init_api_credentials called');
       // error_log('Options: ' . print_r($options, true));
       // error_log('API URL: ' . $this->api_url);
    }


    public function do_status_check() {
        $orders = wc_get_orders(array(
            'status' => array('pending', 'on-hold', 'wc-processing'),
            'payment_method' => array('brazilpays-pix', 'brazilpays-credit'),
            'date_created' => '>' . (strtotime('tomorrow') - 8 * DAY_IN_SECONDS), // Últimos 7 dias
            'limit' => 50 // Limite para evitar sobrecarga
        ));

        foreach ($orders as $order) {
            $transaction_id = $order->get_meta('brazilpays_transaction_id');
            if (!$transaction_id) {
                continue;
            }

            $status = $this->check_order_status($transaction_id);
            $this->update_order_status($order, $status);
        }
    }

    private function check_order_status($transaction_id) {
        $token = $this->get_auth_token();
        if (!$token) {
            return false;
        }

        $url = $this->api_url . '/Charge/' . $transaction_id;
        $response = wp_remote_get($url, array(
            'headers' => array('Authorization' => 'Bearer ' . $token),
        ));

        if (is_wp_error($response) || wp_remote_retrieve_response_code($response) != 200) {
            return false;
        }

        $body = wp_remote_retrieve_body($response);
        $data = json_decode($body, true);

        return $data['data']['paymentStatus'] ?? false;
    }

    private function update_order_status($order, $payment_status) {
        if ($payment_status === false) {
            return;
        }

        $disable_emails = true;

            switch ($payment_status) {
                case 0:
                    //$order->update_status('wc-processing', __('Pagamento pendente.', 'brazilpays-plugin'), $disable_emails);
                    break;
                case 1:
                    $order->update_meta_data('pago', true);
                    $order->update_status('completed', __('Pagamento concluído.', 'brazilpays-plugin'), $disable_emails);
                    break;
                case 2:
                case 3:
                    $order->update_status('failed', __('Pagamento falhou.', 'brazilpays-plugin'), $disable_emails);
                    break;
                case 4:
                    $order->update_status('cancelled', __('Pagamento cancelado.', 'brazilpays-plugin'), $disable_emails);
                    break;
                case 6:
                    $order->update_status('refunded', __('Pagamento reembolsado.', 'brazilpays-plugin'), $disable_emails);
                    break;
            }

        $order->save();
    }

    private function get_auth_token() {
        $cached_token = get_transient('brazilpays_token');
        if ($cached_token) {
            return $cached_token;
        }

        $response = wp_remote_post($this->api_url . '/Merchant/External/Token', array(
            'headers' => array(
                'merchantCode' => $this->merchant_code,
                'publicKey' => $this->public_key
            ),
            'timeout' => 30
        ));

        if (is_wp_error($response) || wp_remote_retrieve_response_code($response) !== 200) {
            return null;
        }

        $body = wp_remote_retrieve_body($response);
        $data = json_decode($body, true);
        $token = $data['data']['access_token'] ?? null;
        $expires_in = $data['data']['expires_in'] ?? 3600;

        if ($token) {
            set_transient('brazilpays_token', $token, $expires_in);
        }

        return $token;
    }
}

// Inicializar a classe
new BrazilPays_Cron_Status_Check();