<?php
class BrazilPaysEnvironment {
    private static $instance = null;
    private $environment;
    private $api_urls;
    private $merchant_code;
    private $public_key;
    private function __construct() {
        
        $options = get_option('brazilpays_options', array());
        $this->environment = isset($options['environment']) ? $options['environment'] : 'production';
        $this->merchant_code = isset($options['merchant_code']) ? $options['merchant_code'] : '';
        $this->public_key = isset($options['public_key']) ? $options['public_key'] : '';
        $this->api_urls = [
            'production' => 'https://api-brazilpays.megaleios.com/api/v1',
            'homologation' => 'https://apihom.megaleios.com/ApiBrazilPaysHml/api/v1'
        ];
    }

    public static function getInstance() {
        if (self::$instance == null) {
            self::$instance = new BrazilPaysEnvironment();
        }
        return self::$instance;
    }

    public function getApiUrl() {
        return $this->api_urls[$this->environment];
    }

    public function getMerchantCode() {
        return $this->merchant_code;
    }

    public function getPublicKey() {
        return $this->public_key;
    }

    public function setEnvironment($env) {
        if (array_key_exists($env, $this->api_urls)) {
            $this->environment = $env;
            $this->updateOptions();
        }
    }

    public function setMerchantCode($code) {
        $this->merchant_code = $code;
        $this->updateOptions();
    }

    public function setPublicKey($key) {
        $this->public_key = $key;
        $this->updateOptions();
    }

    private function updateOptions() {
        $options = get_option('brazilpays_options', array());
        $options['environment'] = $this->environment;
        $options['merchant_code'] = $this->merchant_code;
        $options['public_key'] = $this->public_key;
        update_option('brazilpays_options', $options);
    }

    public function getEnvironment() {
        return $this->environment;
    }
}